# GNU Solfege - free ear training software
# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2007, 2008  Tom Cato Amundsen
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

DEFAULT_VELOCITY = 100
DEFAULT_VOLUME = 100

PPPP = 30
PPP  = 35
PP   = 40
P    = 50
MP   = 60
MF   = 64
F    = 90
FF   = 100
FFF  = 110
FFFF = 115

ALL = 0
FIRST = 1
LAST = 2

UP = 'UP'
BOTH = 'BOTH'
DOWN = 'DOWN'

START_NOTE = 'start-note'
STOP_NOTE  = 'stop-note'
DELTA      = 'delta'

ACCIDENTAL__2 = -2
ACCIDENTAL__1 = -1
ACCIDENTAL_0 = 0
ACCIDENTAL_1 = 1
ACCIDENTAL_2 = 2
NOTEHEAD_0 = 0# 1/1
NOTEHEAD_1 = 1# 1/2
NOTEHEAD_2 = 2# 1/4

FLAG_8UP = 'u3'
FLAG_8DOWN = 'd3'
FLAG_16UP = 'u4'
FLAG_16DOWN = 'd4'
FLAG_32UP = 'u5'
FLAG_32DOWN = 'd5'
FLAG_64UP = 'u6'
FLAG_64DOWN = 'd6'
DOT = 19
REST_1 = 20
REST_2 = 21
REST_4 = 22
REST_8 = 23
REST_16 = 24
REST_32 = 25
REST_64 = 26
NUMBER_2 = 27
NUMBER_3 = 28
NUMBER_4 = 29
NUMBER_5 = 30
NUMBER_6 = 31
NUMBER_7 = 32
NUMBER_8 = 33
NUMBER_9 = 34
